@@ -17,6 +17,12 @@ use Test::More;
 
 use MockCpsrvd::cpanel;
 
+use constant _CP_REQUIRE => (
+    'HTTP::Request',
+    'HTTP::Response',
+    'IO::Socket::SSL',
+);
+
 sub TRANSPORT {
     my ($self) = @_;
 
